@@ -1,6 +1,6 @@
 {-# LANGUAGE OverloadedStrings, GeneralizedNewtypeDeriving, RecordWildCards,
     MultiParamTypeClasses, FunctionalDependencies, FlexibleInstances, CPP,
-    DeriveDataTypeable #-}
+    DeriveDataTypeable, StandaloneDeriving #-}
 
 module Database.Redis.Core (
     Connection(..), ConnectError(..), connect, checkedConnect, disconnect,
@@ -18,14 +18,15 @@ import Control.Applicative
 #endif
 import Control.Exception
 import Control.Monad.Reader
+import qualified Control.Monad.Catch as Catch
 import qualified Data.ByteString as B
 import Data.IORef
 import Data.Pool
 import Data.Time
 import Data.Typeable
-import Network
+import qualified Network.Socket as NS
 import Network.TLS (ClientParams)
-
+import Database.Redis.Core.Internal
 import Database.Redis.Protocol
 import qualified Database.Redis.ProtocolPipelining as PP
 import Database.Redis.Types
@@ -35,16 +36,6 @@ import Database.Redis.Types
 -- The Redis Monad
 --
 
--- |Context for normal command execution, outside of transactions. Use
---  'runRedis' to run actions of this type.
---
---  In this context, each result is wrapped in an 'Either' to account for the
---  possibility of Redis returning an 'Error' reply.
-newtype Redis a = Redis (ReaderT RedisEnv IO a)
-    deriving (Monad, MonadIO, Functor, Applicative)
-
-data RedisEnv = Env { envConn :: PP.Connection, envLastReply :: IORef Reply }
-
 -- |This class captures the following behaviour: In a context @m@, a command
 --  will return its result wrapped in a \"container\" of type @f@.
 --
@@ -155,8 +146,8 @@ newtype Connection = Conn (Pool PP.Connection)
 -- @
 --
 data ConnectInfo = ConnInfo
-    { connectHost           :: HostName
-    , connectPort           :: PortID
+    { connectHost           :: NS.HostName
+    , connectPort           :: PP.PortID
     , connectAuth           :: Maybe B.ByteString
     -- ^ When the server is protected by a password, set 'connectAuth' to 'Just'
     --   the password. Each connection will then authenticate by the 'auth'
@@ -201,7 +192,7 @@ instance Exception ConnectError
 defaultConnectInfo :: ConnectInfo
 defaultConnectInfo = ConnInfo
     { connectHost           = "localhost"
-    , connectPort           = PortNumber 6379
+    , connectPort           = PP.PortNumber 6379
     , connectAuth           = Nothing
     , connectDatabase       = 0
     , connectMaxConnections = 50
@@ -260,12 +251,12 @@ disconnect :: Connection -> IO ()
 disconnect (Conn pool) = destroyAllResources pool
 
 -- | Memory bracket around 'connect' and 'disconnect'. 
-withConnect :: ConnectInfo -> (Connection -> IO c) -> IO c
-withConnect connInfo = bracket (connect connInfo) disconnect
+withConnect :: (Catch.MonadMask m, MonadIO m) => ConnectInfo -> (Connection -> m c) -> m c
+withConnect connInfo = Catch.bracket (liftIO $ connect connInfo) (liftIO . disconnect)
 
 -- | Memory bracket around 'checkedConnect' and 'disconnect'
-withCheckedConnect :: ConnectInfo -> (Connection -> IO c) -> IO c
-withCheckedConnect connInfo = bracket (checkedConnect connInfo) disconnect
+withCheckedConnect :: (Catch.MonadMask m, MonadIO m) => ConnectInfo -> (Connection -> m c) -> m c
+withCheckedConnect connInfo = Catch.bracket (liftIO $ checkedConnect connInfo) (liftIO . disconnect)
 
 -- The AUTH command. It has to be here because it is used in 'connect'.
 auth
