@@ -62,6 +62,8 @@ data Slowlog = Slowlog
       -- ^ The amount of time needed for its execution, in microseconds.
     , slowlogCmd       :: [ByteString]
       -- ^ The command and it's arguments.
+    , slowlogClientIpAndPort :: Maybe ByteString
+    , slowlogClientName :: Maybe ByteString
     } deriving (Show, Eq)
 
 instance RedisResult Slowlog where
@@ -70,6 +72,16 @@ instance RedisResult Slowlog where
         slowlogTimestamp <- decode timestamp
         slowlogMicros    <- decode micros
         slowlogCmd       <- decode cmd
+        let slowlogClientIpAndPort = Nothing
+            slowlogClientName = Nothing
+        return Slowlog{..}
+    decode (MultiBulk (Just [logId,timestamp,micros,cmd,ip,cname])) = do
+        slowlogId        <- decode logId
+        slowlogTimestamp <- decode timestamp
+        slowlogMicros    <- decode micros
+        slowlogCmd       <- decode cmd
+        slowlogClientIpAndPort <- Just <$> decode ip
+        slowlogClientName <- Just <$> decode cname
         return Slowlog{..}
     decode r = Left r
 
@@ -799,7 +811,7 @@ xaddOpts
     -> TrimOpts
     -> m (f ByteString)
 xaddOpts key entryId fieldValues opts = sendRequest $
-    ["XADD", key, entryId] ++ optArgs ++ fieldArgs
+    ["XADD", key] ++ optArgs ++ [entryId] ++ fieldArgs
     where
         fieldArgs = concatMap (\(x,y) -> [x,y]) fieldValues
         optArgs = case opts of
@@ -937,9 +949,9 @@ xack
     :: (RedisCtx m f)
     => ByteString -- ^ stream
     -> ByteString -- ^ group name
-    -> ByteString -- ^ message ID
+    -> [ByteString] -- ^ message IDs
     -> m (f Integer)
-xack stream groupName messageId = sendRequest ["XACK", stream, groupName, messageId]
+xack stream groupName messageIds = sendRequest $ ["XACK", stream, groupName] ++ messageIds
 
 xrange
     :: (RedisCtx m f)
@@ -1182,3 +1194,6 @@ xtrim stream opts = sendRequest $ ["XTRIM", stream] ++ optArgs
             NoArgs -> []
             Maxlen max -> ["MAXLEN", encode max]
             ApproxMaxlen max -> ["MAXLEN", "~", encode max]
+
+inf :: RealFloat a => a
+inf = 1 / 0
