@@ -357,6 +357,7 @@ testZSets = testCase "sorted sets" $ do
     zrevrangeWithscores "key" 0 1                     >>=? [("v3",42),("v2",2)]
     zrangebyscore "key" 0.5 1.5                       >>=? ["v1"]
     zrangebyscoreWithscores "key" 0.5 1.5             >>=? [("v1",1)]
+    zrangebyscoreWithscores "key" (-inf) inf          >>=? [("v1",1.0),("v2",2.0),("v3",42.0)]
     zrangebyscoreLimit "key" 0.5 2.5 0 1              >>=? ["v1"]
     zrangebyscoreWithscoresLimit "key" 0.5 2.5 0 1    >>=? [("v1",1)]
     zrevrangebyscore "key" 1.5 0.5                    >>=? ["v1"]
@@ -675,7 +676,7 @@ testXReadGroup = testCase "XGROUP */xreadgroup/xack" $ do
             stream = "somestream",
             records = [StreamsRecord{recordId = "123-0", keyValues = [("key", "value")]}]
         }]
-    xack "somestream" "somegroup" "123-0" >>=? 1
+    xack "somestream" "somegroup" ["123-0"] >>=? 1
     xreadGroup "somegroup" "consumer1" [("somestream", ">")] >>=? Nothing
     xgroupSetId "somestream" "somegroup" "0" >>=? Ok
     xgroupDelConsumer "somestream" "somegroup" "consumer1" >>=? 0
@@ -726,7 +727,7 @@ testXClaim =
     xreadGroupOpts
       "somegroup"
       "consumer1"
-      [("somestream", "0")]
+      [("somestream", ">")]
       (defaultXreadOpts {recordCount = Just 2}) >>=?
       Just
         [ XReadResponse
@@ -755,7 +756,7 @@ testXInfo = testCase "xinfo" $ do
     xadd "somestream" "121" [("key1", "value1")]
     xadd "somestream" "122" [("key2", "value2")]
     xgroupCreate "somestream" "somegroup" "0"
-    xreadGroupOpts "somegroup" "consumer1" [("somestream", "0")] (defaultXreadOpts { recordCount = Just 2})
+    xreadGroupOpts "somegroup" "consumer1" [("somestream", ">")] (defaultXreadOpts { recordCount = Just 2})
     consumerInfos <- xinfoConsumers "somestream" "somegroup"
     liftIO $ case consumerInfos of
         Left reply -> HUnit.assertFailure $ "Redis error: " ++ show reply
